---
jupyter:
  jupytext:
    text_representation:
      extension: .md
      format_name: markdown
      format_version: '1.3'
      jupytext_version: 1.16.4
  kernelspec:
    display_name: Python 3 (ipykernel)
    language: python
    name: python3
---

# Welcome to the CRS!

This is a JupyterLab session running on your CRS board. From here, you can immediately interact with the board:

```python
import rfmux
```

```python
s = rfmux.load_session('!HardwareMap [ !CRS { serial: "0033" } ]') # Replace with your board serial
crs = s.query(rfmux.CRS).one()
await crs.resolve()
await crs.set_timestamp_port(crs.TIMESTAMP_PORT.TEST)
```

Please take the time to browse the documentation tree in the left-hand panel.

Python code you create or modify in Jupyter lives on the CRS's MicroSD card. 
